Changelog
=========

Version 0.0.3, 2023-02-27
-----------------------

- Added Option to provide additional include directories over CLI.
- Added Option to provide additional include directories to IncludeResolver.
- Added possibility to merge values in nested dictionaries on include.
